@@ -1,6 +1,7 @@
 #' @title Cell object for FlexTable
 #'
 #' @description Create a representation of a cell that can be inserted in a FlexRow.
+#' For internal usage.
 #' 
 #' @param value a content value - a value of type \code{character} or \code{\link{pot}} or \code{\link{set_of_paragraphs}}.
 #' @param colspan defines the number of columns the cell should span
@@ -9,7 +10,7 @@
 #' @export
 #' @seealso \code{\link{addFlexTable}}, \code{\link{addHeaderRow}}, \code{\link{addFooterRow}}
 #' @examples 
-#' #START_TAG_TEST
+#' \donttest{
 #' @example examples/FlexCell.R
 #' @example examples/STOP_TAG_TEST.R
 FlexCell = function( value, colspan = 1, par.properties = parProperties(), cell.properties = cellProperties() ) {
@@ -38,19 +39,8 @@ FlexCell = function( value, colspan = 1, par.properties = parProperties(), cell.
 	if( !inherits(value, "set_of_paragraphs") )
 		stop("argument value must be a character vector or an object of class 'set_of_paragraphs'.")
 	
-	parset = .jnew( class.ParagraphSet, .jParProperties(par.properties) )
-	for( pot_index in 1:length( value ) ){
-		paragrah = .jnew(class.Paragraph )
-		pot_value = value[[pot_index]]
-		for( i in 1:length(pot_value)){
-			if( is.null( pot_value[[i]]$format ) ) 
-				.jcall( paragrah, "V", "addText", pot_value[[i]]$value )
-			else .jcall( paragrah, "V", "addText", pot_value[[i]]$value, 
-						.jTextProperties( pot_value[[i]]$format) )
-		}
-		.jcall( parset, "V", "addParagraph", paragrah )
-	}
-	
+	parset = .jset_of_paragraphs(value, par.properties)
+		
 	jcellProp = .jCellProperties(cell.properties)
 
 	flexCell = .jnew(class.FlexCell, parset, jcellProp)
