@@ -9,12 +9,16 @@
 #' Not used if file or rscript is provided.
 #' @param rscript an object of class \code{RScript}. 
 #' Not used if file or text is provided.
+#' @param append boolean default to FALSE. If TRUE, paragraphs will be 
+#' appened in the current shape instead of beeing sent into a new shape. 
+#' Paragraphs can only be appended on shape containing paragraphs (i.e. you 
+#' can not add paragraphs after a FlexTable).
 #' @param ... further arguments, not used. 
 #' @details 
 #' You have to one of the following argument: file or text or rscript. 
 #' @return an object of class \code{\link{pptx}}.
 #' @examples
-#' #START_TAG_TEST
+#' \donttest{
 #' doc.filename = "addRScript_example.pptx"
 #' # Create a new document 
 #' doc = pptx( title = "title" )
@@ -28,15 +32,16 @@
 #' @seealso \code{\link{pptx}}, \code{\link{addRScript}}
 #' @method addRScript pptx
 #' @S3method addRScript pptx
-addRScript.pptx = function(doc, rscript, file, text, ... ) {
+addRScript.pptx = function(doc, rscript, file, text, append = FALSE, ... ) {
 	
 	if( !missing ( file ) ){
 		rscript = RScript( file = file, ... )
 	} else if( !missing ( text ) ){
 		rscript = RScript( text = text, ... )
 	} 
-	
-	out = .jcall( doc$current_slide, "I", "add", rscript$jobj )
+	if( !append )
+		out = .jcall( doc$current_slide, "I", "add", rscript$jobj )
+	else out = .jcall( doc$current_slide, "I", "append", rscript$jobj )
 	if( isSlideError( out ) ){
 		stop( getSlideErrorString( out , "RScript") )
 	}
