@@ -1,10 +1,11 @@
 #' @title Insert a title into a docx object
 #'
-#' @description Add a title into a \code{"docx"} object.
+#' @description Add a title into a \code{\link{docx}} object.
 #' 
-#' @param doc Object of class \code{"docx"}
+#' @param doc Object of class \code{\link{docx}}
 #' @param value \code{"character"} value to use as title text
-#' @param level \code{"integer"} positive value to use as heading level. 1 for title1, 2 for title2, etc.
+#' @param level \code{"integer"} positive value to use as 
+#' heading level. 1 for title1, 2 for title2, etc. Default to 1.
 #' @param ... further arguments, not used. 
 #' @details 
 #' 
@@ -20,9 +21,9 @@
 #' You have to use function \code{\link{declareTitlesStyles.docx}} to indicate 
 #' which available styles are meant to be used as titles styles. A side effect is that you 
 #' will be able then to add a table of content in your Word document.
-#' @return an object of class \code{"docx"}.
+#' @return an object of class \code{\link{docx}}.
 #' @examples
-#' #START_TAG_TEST
+#' \donttest{
 #' # Create a new document 
 #' doc = docx( title = "title" )
 #' 
@@ -35,20 +36,24 @@
 #' 
 #' # Write the object in file "addTitle_example.docx"
 #' writeDoc( doc, "addTitle_example.docx" )
-#' #STOP_TAG_TEST
+#' }
 #' @seealso \code{\link{docx}}, \code{\link{addParagraph.docx}}
 #' , \code{\link{declareTitlesStyles.docx}}, \code{\link{styles.docx}}
 #' @method addTitle docx
 #' @S3method addTitle docx
-addTitle.docx = function( doc, value, level, ... ) {
+addTitle.docx = function( doc, value, level = 1, ... ) {
 	if( length( doc$header.styles ) == 0 ){
 		stop("You must defined title styles via declareTitlesStyles first.")				
 	}
 	if( length( doc$header.styles ) < level ){
 		stop("level = ", level, ". You defined only ", length( doc$header.styles ), " styles.")				
 	}
+	if( !is.numeric( level ) )
+		stop("level must be an integer vector of length 1.")
+	if( length( level ) != 1 )
+		stop("level must be an integer vector of length 1.")
 	
-	doc = addParagraph(doc, value, doc$header.styles[level] );
+	doc = addParagraph(doc = doc, value, stylename = doc$header.styles[level] );
 	doc
 }
 
