@@ -3,8 +3,13 @@
 #' @description
 #' Create a \code{\link{docx}} object
 #' 
-#' @param title \code{"character"} value: title of the document (in the doc properties).
-#' @param template \code{"character"} value, it represents the filename of the docx file used as a template.
+#' @param title \code{"character"} value: title of the 
+#' document (in the doc properties).
+#' @param template \code{"character"} value, it represents 
+#' the filename of the docx file used as a template.
+#' @param list.definition a list definition to specify how ordered and unordered 
+#' lists have to be formated. See \code{\link{list.settings}}. Default to 
+#' \code{getOption("ReporteRs-list-definition")}.
 #' @return an object of class \code{\link{docx}}.
 #' @details
 #' Several methods can used to send R output into an object of class \code{\link{docx}}.
@@ -15,6 +20,7 @@
 #'   \item \code{\link{addPlot.docx}} add plots
 #'   \item \code{\link{addFlexTable.docx}} add tables. See \code{\link{FlexTable}}
 #'   \item \code{\link{addImage.docx}} add external images
+#'   \item \code{\link{addMarkdown.docx}} add markdown text
 #'   \item \code{\link{addTOC.docx}} add table of content
 #'   \item \code{\link{addPageBreak.docx}} add page break
 #'   \item \code{\link{addSection.docx}} add section
@@ -28,19 +34,12 @@
 #' @note Word 2007-2013 (*.docx) file formats are the only supported files.\cr Document are manipulated in-memory ; a \code{docx}'s document is not written to the disk unless the \code{\link{writeDoc}} method has been called on the object.
 #' @export
 #' @examples
-#' #START_TAG_TEST
+#' \donttest{
 #' @example examples/docx_example.R
 #' @example examples/STOP_TAG_TEST.R
-#' @seealso \code{\link{addTitle.docx}}, \code{\link{addImage.docx}}, 
-#' \code{\link{addParagraph.docx}}, 
-#' \code{\link{addFlexTable.docx}}, 
-#' \code{\link{addPlot.docx}}, 
-#' \code{\link{addSection.docx}}, 
-#' \code{\link{addTOC.docx}},
-#' \code{\link{styles.docx}}, 
-#' \code{\link{writeDoc.docx}}, 
+#' @seealso \code{\link{bsdoc}}, \code{\link{pptx}}, 
 #' \code{\link{bookmark}}
-docx = function( title = "untitled", template){
+docx = function( title = "untitled", template, list.definition = getOption("ReporteRs-list-definition") ){
 	
 	# docx base file mngt
 	if( missing( template ) )
@@ -50,9 +49,10 @@ docx = function( title = "untitled", template){
 	if( !file.exists( template ) || .reg < 1 )
 		stop(template , " is not a valid file.")
 	
+	lidef = do.call( list.settings, list.definition )
 	# java calls
 	obj = .jnew( class.docx4r.document )
-	.jcall( obj, "V", "setBaseDocument", template )
+	.jcall( obj, "V", "setBaseDocument", template, lidef )
 	.sysenv = Sys.getenv(c("USERDOMAIN","COMPUTERNAME","USERNAME"))
 	
 	.jcall( obj, "V", "setDocPropertyTitle", title )
