@@ -1,7 +1,7 @@
 #' @title Set of paragraphs of text
 #'
 #' @description
-#' Create a container of paragraphs of text (\code{pot} objects). 
+#' Create a container of paragraphs of text (\code{\link{pot}} objects). 
 #' 
 #' @param ... pot objects, one per paragraph.
 #' @details each pot are representing a paragraph. 
@@ -9,14 +9,16 @@
 #' Objects of class \code{set_of_paragraphs} are to be used with \code{\link{addParagraph}}.
 #' @export
 #' @examples
-#' #START_TAG_TEST
+#' \donttest{
 #' pot1 = pot("My tailor", textProperties(color="red") ) + " is " + pot("rich"
 #' 	, textProperties(font.weight="bold") )
 #' pot2 = pot("Cats", textProperties(color="red") ) + " and " + pot("Dogs"
 #' 	, textProperties(color="blue") )
 #' my.pars = set_of_paragraphs( pot1, pot2 )
-#' #STOP_TAG_TEST
-#' @seealso \code{\link{addParagraph}}, \code{\link{addParagraph.docx}}, \code{\link{addParagraph.pptx}}, \code{\link{addParagraph.html}}
+#' }
+#' @seealso \code{\link{addParagraph}}, \code{\link{addParagraph.docx}}, 
+#' \code{\link{addParagraph.pptx}}, \code{\link{addParagraph.bsdoc}},
+#' \code{\link{pot}} 
 set_of_paragraphs = function( ... ){
 	
 	.Object = list(...)
@@ -24,8 +26,15 @@ set_of_paragraphs = function( ... ){
 		if( !all( sapply( .Object , inherits, c("pot", "character") ) ) )
 			stop("set_of_paragraphs can only contains pot objects.")
 		# cast characters as pot if any
-		.Object = lapply( .Object, function( x ) if( inherits(x, "character") ) pot(x) else x )
+		.Object = lapply( .Object, 
+				function( x ) {
+					if( inherits(x, "character") ) {
+						pot( gsub("(\\n|\\r)", "", x ) )
+					} else x 
+				}
+			)
 	} else .Object = list()
+
 	
 	class( .Object ) = c("set_of_paragraphs")
 	.Object
@@ -46,7 +55,7 @@ set_of_paragraphs = function( ... ){
 #' pot2 = pot("Cats", textProperties(color="red") ) + " and " + pot("Dogs"
 #' 	, textProperties(color="blue") )
 #' my.pars = add.pot( my.pars, pot2 )
-#' @seealso \code{\link{set_of_paragraphs}}, \code{\link{addParagraph}}, \code{\link{addParagraph.docx}}, \code{\link{addParagraph.pptx}}, \code{\link{addParagraph.html}}
+#' @seealso \code{\link{set_of_paragraphs}}, \code{\link{pot}}
 add.pot = function( x, value ){
 	if ( class( x )!= "set_of_paragraphs" )
 		stop("x must be a set_of_paragraphs object.")
