@@ -22,6 +22,7 @@ import org.docx4j.wml.PPr;
 import org.lysis.reporters.formats.ParProperties;
 import org.lysis.reporters.formats.TextProperties;
 import org.lysis.reporters.html4r.tools.Format;
+import org.lysis.reporters.lists.NumberingDefinition;
 import org.lysis.reporters.tools.DOCX4R;
 import org.lysis.reporters.tools.DocComponent;
 import org.lysis.reporters.tools.HTML4R;
@@ -32,9 +33,8 @@ import org.pptx4j.pml.Shape;
 public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R{
 	
 	private LinkedHashMap<Integer, Paragraph> parList;
-	private String tag;
 	
-	private static String SAMPLE_SHAPE_START =                         
+	private static String SAMPLE_SHAPE_START = 
             "<p:sp xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\">"
             + "<p:nvSpPr>"
 	            + "<p:cNvPr id=\"${id_shape}\" name=\"Title ${title_shape}\" />"
@@ -42,7 +42,7 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 		                    + "<a:spLocks noGrp=\"${noGrp}\" />"
 		            + "</p:cNvSpPr>"
 	            + "<p:nvPr>"
-                    + "<p:ph idx=\"${idx}\"/>"//+ "<p:ph idx=\"${idx}\" ${size}/>"
+                    + "<p:ph idx=\"${idx}\"/>"
 	            + "</p:nvPr>"
 		    + "</p:nvSpPr>"
 		    + "<p:spPr>"
@@ -59,8 +59,6 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 		super();
 		setParProperties(parProp);
 		parList = new LinkedHashMap<Integer, Paragraph>();
-		setParProperties( parProp );
-		setTag("div");
 	}
 	
 	public void addParagraph ( Paragraph par ){
@@ -74,9 +72,10 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 	public Paragraph getLast(){
 		return parList.get(size()-1);
 	}
-	public void setTag( String t ){
-		tag = t;
+	public Paragraph get(int i){
+		return parList.get(i);
 	}
+
 	
 	/* used with alterFlexTable */
 	public void setTextProperties(TextProperties tp){
@@ -100,39 +99,59 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 	@Override
 	public String getHTML() {
 		if( size() < 1 ) return "";
+		String ls = getParProperties().getListStyle();
+
+		if( ls.equals("ordered") || ls.equals("unordered") ){
+			counters.add(getCSSCounterName());
+			if( !numbDefinition.hasListPointer((int)list_id) ){
+				numbDefinition.addListPointer((int)list_id, ls.equals("ordered") );
+			}
+			int pl = 0;
+			if( ls.equals("ordered") )
+				pl = numbDefinition.getOrdered().getLevelDefintion(getParProperties().getLevel()).getPaddingLeft();
+			else pl = numbDefinition.getUnordered().getLevelDefintion(getParProperties().getLevel()).getPaddingLeft();
+			getParProperties().setPaddingLeft( pl );
+		} 
 		
 		LinkedHashMap<String, String> ppr = getParProperties().get_html_pp();
+		
 		String out = "";
-		String elt_tag_beg = "<p>";
-		String elt_tag_end = "</p>";
+		String elt_tag_beg = "";
+		String elt_tag_end = "";
+
+		String styleStr = "";
 		
-		if( tag.equals("ul") || tag.equals("ol") ) {
-			elt_tag_beg = "<li>";
-			elt_tag_end = "</p>";
-		} else if( tag.equals("pre") ) {
-			elt_tag_beg = "";
-			elt_tag_end = "";
-		}
+		styleStr = " style=\"" + Format.getJSString(ppr) + "\"";
 		
-		if( !tag.equals("pre") ){
-			out = "<" + tag + " style=\"";
-			String styleStr = Format.getJSString(ppr);
-			out = out + styleStr + "\">";
+		if( getParProperties().getListStyle().equals("ordered") || getParProperties().getListStyle().equals("unordered") ){
+			elt_tag_beg = "<dl class=\"" + getCSSClassName() + " dl_reporters\"><dt" + styleStr + ">";
+			elt_tag_end = "</dt></dl>";
+		} else if( getParProperties().getListStyle().equals("blockquote") ){
+			for( int depth = 0 ; depth < getParProperties().getLevel() ; depth ++){
+				elt_tag_beg += "<blockquote>";
+				elt_tag_end += "</blockquote>";
+			}
 		} else {
-			out = "<" + tag + ">";
+			elt_tag_beg = "<p" + styleStr + ">";
+			elt_tag_end = "</p>";
 		}
-		
-		for(int i = 0 ; i < size(); i++ ){
-			out += elt_tag_beg + parList.get(i).getHTML() + elt_tag_end;
+		for(int i = 0 ; i < size(); i++ ) parList.get(i).setHTMLReference(list_id, counters, numbDefinition);
+		if( !getParProperties().getListStyle().equals("blockquote") ){
+			for(int i = 0 ; i < size(); i++ ){
+				out += elt_tag_beg + parList.get(i).getHTML() + elt_tag_end;
+			}
+		} else {
+			out += elt_tag_beg;
+			for(int i = 0 ; i < size(); i++ ){
+				out += "<p" + styleStr + ">" + parList.get(i).getHTML() + "</p>";
+			}
+			out += elt_tag_end;
 		}
-		
-		out += "</" + tag + ">";
-		
+				
 		return out;
 	}
 
-	public Shape get_pptx_elt() throws Exception{
-		
+	private Shape get_pptx_shape() throws Exception{
 		if( !validatePPTXComponent() ) throw new Exception("class ParagraphSet: elements need to be set...");
 
 		java.util.HashMap<String, String>mappings = new java.util.HashMap<String, String>();
@@ -146,21 +165,41 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
         mappings.put("offy", "" + getOffy() );
 
         Shape o = (Shape) XmlUtils.unmarshallFromTemplate(SAMPLE_SHAPE_START + "<a:p/>" + SAMPLE_SHAPE_END, mappings,Context.jcPML, Shape.class);
+        return o;
+	}
+	
+	public Shape get_pptx_elt() throws Exception{	
+    	Shape o = get_pptx_shape();
     	o.setTxBody(get_pptx_parset());
-
+//    	if( getParProperties().hasShadingColor() ){
+//        	String color = getParProperties().getShadingColor();
+//        	o.getSpPr().setSolidFill(org.lysis.reporters.pptx4r.tools.Format.getCol(color));    		
+//    	}
+		return o;
+	}
+		
+	public Shape get_pptx_elt(NumberingDefinition nb, int startNumbering) throws Exception{	
+    	Shape o = get_pptx_shape();
+    	o.setTxBody(get_pptx_parset(nb, startNumbering));
+//    	if( getParProperties().hasShadingColor() ){
+//        	String color = getParProperties().getShadingColor();
+//        	o.getSpPr().setSolidFill(org.lysis.reporters.pptx4r.tools.Format.getCol(color));    		
+//    	}
 		return o;
 	}
 	
-	public CTTextBody get_pptx_parset() throws Exception{
-		CTTextParagraphProperties rpr = getParProperties().get_pptx_pp();
+	private CTTextBody get_pptx_with_rpr(CTTextParagraphProperties rpr) throws Exception{
+		
 		Vector<CTTextParagraph> out = new Vector<CTTextParagraph>();
 		if( size() > 0 ){
 			for(int i = 0 ; i < size() ; i++ ){
-				CTTextParagraph temp = parList.get(i).get_pptx_par();
+
+				CTTextParagraph temp = parList.get(i).getPptxTextParagraph(slidePart);
 				temp.setPPr(rpr);
 				out.add( temp );
 			}
 		}
+
 		CTTextBody tb = new CTTextBody();
 		
 		CTTextBodyProperties pp = new CTTextBodyProperties();
@@ -172,39 +211,71 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 		return tb;
 	}
 	
+	public CTTextBody get_pptx_parset() throws Exception{
+		CTTextParagraphProperties rpr = getParProperties().get_pptx_pp();
+		return get_pptx_with_rpr(rpr);
+	}
+
+	public CTTextBody get_pptx_parset(NumberingDefinition nb, int startNumbering) throws Exception{
+		CTTextParagraphProperties rpr = getParProperties().get_pptx_pp(nb, startNumbering);
+		return get_pptx_with_rpr(rpr);
+	}	
+	
 	public boolean validateDOCXComponent(){
 		if( getPPr() == null ) {
 			return false;
 		}
+
+		if( ordered_num_id < 1 ) return false;
 		return true;
 	}
+
 	public Vector<P> get_docx_elt() throws Exception{
 		Vector<P> out = new Vector<P>();
 		
-		if( !validateDOCXComponent() ) throw new Exception("class ParagraphSet: elements need to be set...");
+		if( !validateDOCXComponent() ) 
+			throw new Exception("class ParagraphSet: elements need to be set...");
 
 		PPr rpr = getPPr();
-		
 		if( size() > 0 ){
 			for(int i = 0 ; i < size() ; i++ ){
-				P temp = parList.get(i).get_docx_par();
+				parList.get(i).setNumberingDefinitionsPart(ndp);
+				parList.get(i).setOrderedNumID(ordered_num_id);
+				parList.get(i).setUnorderedNumID(unordered_num_id);
+				parList.get(i).setDOCXMLPackage(getDOCXMLPackage());
+				P temp = parList.get(i).getDocxParagraph();
 				temp.setPPr(rpr);
 				if( i == 1 ) addBookmark(temp);
 				out.add( temp );
 			}
 		}
-		
 		return out;
 	}
 
+	private String getCSSSuffix(){
+		return list_id + "-" + getParProperties().getLevel();
+	}
+
+	private String getCSSClassName(){
+		if( getParProperties().getListStyle().equals("ordered") ){
+			return "ol-" + getCSSSuffix();
+		} else if( getParProperties().getListStyle().equals("unordered") ){
+			return "ul-" + getCSSSuffix();
+		} else return "";
+	}
+	
+	public String getCSSCounterName(){
+		return "counter-" + getCSSSuffix();
+	}
+	
 	@Override
 	public String getCSS() {
-		return "";
+		return null ;
 	}
 
 	@Override
 	public String getJS() {
-		return "";
+		return null;
 	}
 
 	@Override
