@@ -2,10 +2,6 @@
  * This file is part of ReporteRs.
  * Copyright (c) 2014, David Gohel All rights reserved.
  *
- * It is inspired from sources of R package grDevices:
- * Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- * Copyright (C) 1998--2014  The R Core Team
- *
  * ReporteRs is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -42,3 +38,6 @@ void register_element(pDevDesc dev);
 
 void closeFile( FILE *file);
 
+void DOC_ClipLine(double x0, double y0, double x1, double y1, pDevDesc dev);
+void DOC_ClipRect(double x0, double y0, double x1, double y1,
+		pDevDesc dev);
