@@ -2,10 +2,6 @@
  * This file is part of ReporteRs.
  * Copyright (c) 2014, David Gohel All rights reserved.
  *
- * It is inspired from sources of R package grDevices:
- * Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- * Copyright (C) 1998--2014  The R Core Team
- *
  * ReporteRs is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -33,6 +29,6 @@ char* get_dml_filename(char* filename, int index);
 void DML_SetFillColor(pDevDesc dev, R_GE_gcontext *gc);
 void DML_SetFontColor(pDevDesc dev, R_GE_gcontext *gc);
 void DML_SetLineSpec(pDevDesc dev, R_GE_gcontext *gc);
-
+void dml_text(const char *str, DOCDesc *pd);
 int get_and_increment_idx(pDevDesc dev);
 
